from fintekkers.models.security import security_pb2 as _security_pb2
from fintekkers.requests.security import create_security_request_pb2 as _create_security_request_pb2
from fintekkers.requests.util.errors import summary_pb2 as _summary_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateSecurityResponseProto(_message.Message):
    __slots__ = ["errors_or_warnings", "object_class", "security_request", "security_response", "version"]
    ERRORS_OR_WARNINGS_FIELD_NUMBER: _ClassVar[int]
    OBJECT_CLASS_FIELD_NUMBER: _ClassVar[int]
    SECURITY_REQUEST_FIELD_NUMBER: _ClassVar[int]
    SECURITY_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    errors_or_warnings: _summary_pb2.SummaryProto
    object_class: str
    security_request: _create_security_request_pb2.CreateSecurityRequestProto
    security_response: _security_pb2.SecurityProto
    version: str
    def __init__(self, object_class: _Optional[str] = ..., version: _Optional[str] = ..., security_request: _Optional[_Union[_create_security_request_pb2.CreateSecurityRequestProto, _Mapping]] = ..., security_response: _Optional[_Union[_security_pb2.SecurityProto, _Mapping]] = ..., errors_or_warnings: _Optional[_Union[_summary_pb2.SummaryProto, _Mapping]] = ...) -> None: ...



from fintekkers.models.util import local_timestamp_pb2 as _local_timestamp_pb2
from fintekkers.models.util import endpoint_pb2 as _endpoint_pb2
from fintekkers.models.util.lock import node_partition_pb2 as _node_partition_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NodeState(_message.Message):
    __slots__ = ["end_point", "is_expired", "last_seen", "object_class", "partition", "version"]
    END_POINT_FIELD_NUMBER: _ClassVar[int]
    IS_EXPIRED_FIELD_NUMBER: _ClassVar[int]
    LAST_SEEN_FIELD_NUMBER: _ClassVar[int]
    OBJECT_CLASS_FIELD_NUMBER: _ClassVar[int]
    PARTITION_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    end_point: _endpoint_pb2.Endpoint
    is_expired: bool
    last_seen: _local_timestamp_pb2.LocalTimestampProto
    object_class: str
    partition: _node_partition_pb2.NodePartition
    version: str
    def __init__(self, object_class: _Optional[str] = ..., version: _Optional[str] = ..., partition: _Optional[_Union[_node_partition_pb2.NodePartition, _Mapping]] = ..., end_point: _Optional[_Union[_endpoint_pb2.Endpoint, _Mapping]] = ..., last_seen: _Optional[_Union[_local_timestamp_pb2.LocalTimestampProto, _Mapping]] = ..., is_expired: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fintekkers/requests/security/query_security_request.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fintekkers.models.util import uuid_pb2 as fintekkers_dot_models_dot_util_dot_uuid__pb2
from fintekkers.models.util import local_timestamp_pb2 as fintekkers_dot_models_dot_util_dot_local__timestamp__pb2
from fintekkers.models.position import position_filter_pb2 as fintekkers_dot_models_dot_position_dot_position__filter__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9fintekkers/requests/security/query_security_request.proto\x12\x1c\x66intekkers.requests.security\x1a!fintekkers/models/util/uuid.proto\x1a,fintekkers/models/util/local_timestamp.proto\x1a\x30\x66intekkers/models/position/position_filter.proto\"\x80\x02\n\x19QuerySecurityRequestProto\x12\x14\n\x0cobject_class\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x30\n\x05uuIds\x18\x15 \x03(\x0b\x32!.fintekkers.models.util.UUIDProto\x12N\n\x15search_security_input\x18\x16 \x01(\x0b\x32/.fintekkers.models.position.PositionFilterProto\x12:\n\x05\x61s_of\x18\x17 \x01(\x0b\x32+.fintekkers.models.util.LocalTimestampProtoB\x1e\x42\x1aQuerySecurityRequestProtosP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.requests.security.query_security_request_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\032QuerySecurityRequestProtosP\001'
  _QUERYSECURITYREQUESTPROTO._serialized_start=223
  _QUERYSECURITYREQUESTPROTO._serialized_end=479
# @@protoc_insertion_point(module_scope)
